# eric7.RemoteServerInterface.EricServerConnectionDialog

Module implementing a dialog to enter the parameters for a connection to an eric-ide server.

### Global Attributes

None

### Classes

EricServerConnectionDialog | Class implementing a dialog to enter the parameters for a connection to an eric-ide server.

### Functions

None

## EricServerConnectionDialog

Class implementing a dialog to enter the parameters for a connection to an eric-ide server.

### Derived from

QDialog, Ui_EricServerConnectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricServerConnectionDialog | Constructor
__updateOK | Private slot to update the enabled state of the OK button.
getData | Public method to get the entered data.
getProfileData | Public method to get the entered data for connection profile mode.
setProfileData | Public method to set the connection profile data to be edited.

### Static Methods

None

#### EricServerConnectionDialog (Constructor)

EricServerConnectionDialog(profileNames=None, parent=None)

Constructor

profileNames (list of str (optional))
  list of defined connection profile names (defaults to None)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### EricServerConnectionDialog.__updateOK

__updateOK()

Private slot to update the enabled state of the OK button.

#### EricServerConnectionDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the entered host name or IP address, the port number and the timeout (in seconds)

Return Type:
  tuple of (str, int, int)

#### EricServerConnectionDialog.getProfileData

getProfileData()

Public method to get the entered data for connection profile mode.

Return:
  tuple containing the profile name, host name or IP address, the port number and the timeout (in seconds)

Return Type:
  tuple of (str, str, int, int)

#### EricServerConnectionDialog.setProfileData

setProfileData(name, hostname, port, timeout)

Public method to set the connection profile data to be edited.

name (str)
  profile name
hostname (str)
  host name or IP address
port (int)
  port number
timeout (int)
  timeout value in seconds

Up